==> scummvm-0.11.1.tar.gz: scummvm-0.11.1/tools/create_kyradat/towns.h <==
const ExtractEntry kyra1FMTownsE[] = {
	{ kKallakWritingSeq, 0x0002F1FF, 0x0002F9F6 },
	{ kMalcolmTreeSeq, 0x0002FCC3, 0x0002FEDB },
	{ kWestwoodLogoSeq, 0x0002FEDB, 0x0002FF26 },
	{ kKyrandiaLogoSeq, 0x0002F9F7, 0x0002FA53 },
	{ kKallakMalcolmSeq, 0x0002FA53, 0x0002FCC0 },
	{ kForestSeq, 0x0002F067, 0x0002F1FD },
	{ kIntroCPSStrings, 0x00027D5A, 0x00027D6F },
	{ kIntroWSAStrings, 0x00027D72, 0x00027E05 },
	{ kIntroCOLStrings, 0x00027E06, 0x00027E36 },
	{ kIntroStrings, 0x00027E36, 0x0002837B },
	{ kRoomList, 0x0002FF90, 0x00036478 },
	{ kRoomFilenames, 0x00028B20,  0x00028E6C},	
	{ kCharacterImageFilenames, 0x0002606E, 0x00026165 },
	{ kDefaultShapes, 0x00037CF9, 0x00038183 },
	{ kItemNames, 0x00029724, 0x00029C29 },		
	{ kTakenStrings, 0x00028978, 0x00028994 },
	{ kPlacedStrings, 0x000289A0, 0x000289A9 },	
	{ kDroppedStrings, 0x000289E4, 0x000289EE },
	{ kNoDropStrings, 0x00027C0E, 0x00027C88 },
	{ kAmuleteAnimSeq, 0x0002A814, 0x0002A83E },
	{ kPaletteList1, 0x0002E80B, 0x0002E820 },
	{ kPaletteList2, 0x0002E823, 0x0002E856 },
	{ kPaletteList3, 0x0002E857, 0x0002E88A },
	{ kPaletteList4, 0x0002E88B, 0x0002E8BE },
	{ kPaletteList5, 0x0002E8BF, 0x0002E8F2 },
	{ kPaletteList6, 0x0002E8F3, 0x0002E926 },
	{ kPaletteList7, 0x0002E927, 0x0002E95D },
	{ kPaletteList8, 0x0002E95F, 0x0002E995 },
	{ kPaletteList9, 0x0002E997, 0x0002E9C4 },
	{ kPaletteList10, 0x0002E9C7, 0x0002E9F4 },
	{ kPaletteList11, 0x0002E9F7, 0x0002EA24 },
	{ kPaletteList12, 0x0002EA27, 0x0002EA54 },
	{ kPaletteList13, 0x0002EA54, 0x0002EA81 },
	{ kPaletteList14, 0x0002EA87, 0x0002EAC3 },
	{ kPaletteList15, 0x0002EAC3, 0x0002EAF0 },
	{ kPaletteList16, 0x0002EAF3, 0x0002EB14 },
	{ kPaletteList17, 0x0002EB17, 0x0002EB38 },
	{ kPaletteList18, 0x0002EB3B, 0x0002EB50 },
	{ kPaletteList19, 0x0002EB53, 0x0002EB68 },
	{ kPaletteList20, 0x0002EB6B, 0x0002EB80 },
	{ kPaletteList21, 0x0002EB83, 0x0002EB98 },
	{ kPaletteList22, 0x0002EB9B, 0x0002EBB0 },
	{ kPaletteList23, 0x0002EBB3, 0x0002EBC8 },
	{ kPaletteList24, 0x0002EBCB, 0x0002EBFB },
	{ kPaletteList25, 0x0002EBFB, 0x0002EC2B },
	{ kPaletteList26, 0x0002EC2B, 0x0002EC5B },
	{ kPaletteList27, 0x0002EC5B, 0x0002EC8B },
	{ kPaletteList28, 0x0002EC8B, 0x0002ECBB },
	{ kPaletteList29, 0x0002ECBB, 0x0002ECEB },
	{ kPaletteList30, 0x0002ECEB, 0x0002ED27 },
	{ kPaletteList31, 0x0002ED27, 0x0002ED4E },
	{ kPaletteList32, 0x0002ED4F, 0x0002ED76 },
	{ kPaletteList33, 0x0002ED77, 0x0002EDB3 },
	{ kPutDownString, 0x00025BD6, 0x00025BFC },	
	{ kWaitAmuletString, 0x00025C2A, 0x00025C67 },
	{ kBlackJewelString, 0x00025C96, 0x00025CB9 },
	{ kHealingTipString, 0x00025CF2, 0x00025D1F },
	{ kPoisonGoneString, 0x00025E06, 0x00025E42 },
	{ kHealing1Shapes, 0x000381F1, 0x0003828B },
	{ kHealing2Shapes, 0x0003828D, 0x0003835F },
	{ kThePoisonStrings, 0x000294B8, 0x0002954A },
	{ kFluteStrings, 0x00025B1E, 0x00025B78 },
	{ kPoisonDeathShapes, 0x0003865D, 0x000386E9 },
	{ kFluteShapes, 0x00038561, 0x0003865D },
	{ kWinter1Shapes, 0x00038361, 0x00038392 },
	{ kWinter2Shapes, 0x00038395, 0x0003848A },
	{ kWinter3Shapes, 0x0003848D, 0x000384A9 },
	{ kDrinkShapes, 0x00038185, 0x000381EF },
	{ kWispShapes, 0x000384A9, 0x0003855F },
	{ kMagicAnimShapes, 0x000386E9, 0x0003870C },
	{ kBranStoneShapes, 0x0003870D, 0x00038770 },
	{ kWispJewelStrings, 0x00025D4E, 0x00025DC3 },
	{ kMagicJewelStrings, 0x00025DE2, 0x00025DF5 },
	{ kFlaskFullString, 0x00029688, 0x000296A4 },
	{ kFullFlaskString, 0x00029568, 0x00029605 },
	{ kOutroReunionSeq, 0x0002B529, 0x0002BA70 },
	{ kOutroHomeString, 0x00025F7E, 0x00025F83 },
	{ kVeryCleverString, 0x00025F8E, 0x00025FC0 },
	{ kGUIStrings, 0x000291E0, 0x000293DC },
	{ kNewGameString, 0x0002919C, 0x000291B1 },
	{ kConfigStrings, 0x00029360, 0x000293AA},
	{ kKyra1TownsSFXTable, 0x0003A978, 0x0004CF80 },
	{ kCreditsStrings, 0x0002AED8, 0x0002B464 },
	{ kMenuSKB, 0x000293DE, 0x000294A7 },
	{ kSjisVTable, 0x0003A421, 0x0003A749 },
	{ -1, 0, 0 }
};

const ExtractEntry kyra1FMTownsJ[] = {
	{ kIntroStrings, 0x0002837C, 0x00028977 },	
	{ kItemNames, 0x00029C2C, 0x0002A1B3 },		
	{ kTakenStrings, 0x00028980, 0x0002899F },
	{ kPlacedStrings, 0x000289AC, 0x000289B9 },	
	{ kDroppedStrings, 0x000289F0, 0x000289FB },
	{ kNoDropStrings, 0x00027C3E, 0x00027C9F },
	{ kPutDownString, 0x00025BFE, 0x00025C27 },	
	{ kWaitAmuletString, 0x00025C6A, 0x00025C93 },
	{ kBlackJewelString, 0x00025CBA, 0x00025CEF },
	{ kHealingTipString, 0x00025D22, 0x00025D4D },
	{ kPoisonGoneString, 0x00025E12, 0x00025E4F },
	{ kThePoisonStrings, 0x000294C8, 0x00029568 },
	{ kFluteStrings, 0x00025B3E, 0x00025B91 },
	{ kWispJewelStrings, 0x00025D7A, 0x00025DE1 },
	{ kMagicJewelStrings, 0x00025DF6, 0x00025E05 },
	{ kFlaskFullString, 0x000296A4, 0x000296C3 },
	{ kFullFlaskString, 0x00029608, 0x00029685 },
	{ kOutroHomeString, 0x00025F86, 0x00025F8D },
	{ kVeryCleverString, 0x00025FC2, 0x00025FF1 },
	{ kGUIStrings, 0x000368D1, 0x00036B30 },
	{ kNewGameString, 0x000291B4, 0x000291CF},
	{ kConfigStrings, 0x000290AC, 0x00029103 },
	{ -1, 0, 0 }
};

const Game kyra1TownsGames[] = {
	{ kKyra1, EN_ANY, kFMTownsVersionE, "5a3ad60ccd0f2e29463e0368cd14a60d", kyra1FMTownsE },
	{ kKyra1, JA_JPN, kFMTownsVersionJ, "5a3ad60ccd0f2e29463e0368cd14a60d", kyra1FMTownsJ },
	GAME_DUMMY_ENTRY
};

==> scummvm_0.13.0-2.tar.gz: scummvm-0.13.0/tools/create_kyradat/towns.h <==
const ExtractEntry kyra1FMTownsE[] = {
	{ kKallakWritingSeq, 0x0002F1FF, 0x0002F9F6 },
	{ kMalcolmTreeSeq, 0x0002FCC3, 0x0002FEDB },
	{ kWestwoodLogoSeq, 0x0002FEDB, 0x0002FF26 },
	{ kKyrandiaLogoSeq, 0x0002F9F7, 0x0002FA53 },
	{ kKallakMalcolmSeq, 0x0002FA53, 0x0002FCC0 },
	{ kForestSeq, 0x0002F067, 0x0002F1FD },
	{ kIntroCPSStrings, 0x00027D5A, 0x00027D6F },
	{ kIntroWSAStrings, 0x00027D72, 0x00027E05 },
	{ kIntroCOLStrings, 0x00027E06, 0x00027E36 },
	{ kIntroStrings, 0x00027E36, 0x0002837B },
	{ kRoomList, 0x0002FF90, 0x00036478 },
	{ kRoomFilenames, 0x00028B20,  0x00028E6C},
	{ kCharacterImageFilenames, 0x0002606E, 0x00026165 },
	{ kDefaultShapes, 0x00037CF9, 0x00038183 },
	{ kItemNames, 0x00029724, 0x00029C29 },
	{ kTakenStrings, 0x00028978, 0x00028994 },
	{ kPlacedStrings, 0x000289A0, 0x000289A9 },
	{ kDroppedStrings, 0x000289E4, 0x000289EE },
	{ kNoDropStrings, 0x00027C0E, 0x00027C88 },
	{ kAmuleteAnimSeq, 0x0002A814, 0x0002A83E },
	{ kPaletteList1, 0x0002E80B, 0x0002E820 },
	{ kPaletteList2, 0x0002E823, 0x0002E856 },
	{ kPaletteList3, 0x0002E857, 0x0002E88A },
	{ kPaletteList4, 0x0002E88B, 0x0002E8BE },
	{ kPaletteList5, 0x0002E8BF, 0x0002E8F2 },
	{ kPaletteList6, 0x0002E8F3, 0x0002E926 },
	{ kPaletteList7, 0x0002E927, 0x0002E95D },
	{ kPaletteList8, 0x0002E95F, 0x0002E995 },
	{ kPaletteList9, 0x0002E997, 0x0002E9C4 },
	{ kPaletteList10, 0x0002E9C7, 0x0002E9F4 },
	{ kPaletteList11, 0x0002E9F7, 0x0002EA24 },
	{ kPaletteList12, 0x0002EA27, 0x0002EA54 },
	{ kPaletteList13, 0x0002EA54, 0x0002EA81 },
	{ kPaletteList14, 0x0002EA87, 0x0002EAC3 },
	{ kPaletteList15, 0x0002EAC3, 0x0002EAF0 },
	{ kPaletteList16, 0x0002EAF3, 0x0002EB14 },
	{ kPaletteList17, 0x0002EB17, 0x0002EB38 },
	{ kPaletteList18, 0x0002EB3B, 0x0002EB50 },
	{ kPaletteList19, 0x0002EB53, 0x0002EB68 },
	{ kPaletteList20, 0x0002EB6B, 0x0002EB80 },
	{ kPaletteList21, 0x0002EB83, 0x0002EB98 },
	{ kPaletteList22, 0x0002EB9B, 0x0002EBB0 },
	{ kPaletteList23, 0x0002EBB3, 0x0002EBC8 },
	{ kPaletteList24, 0x0002EBCB, 0x0002EBFB },
	{ kPaletteList25, 0x0002EBFB, 0x0002EC2B },
	{ kPaletteList26, 0x0002EC2B, 0x0002EC5B },
	{ kPaletteList27, 0x0002EC5B, 0x0002EC8B },
	{ kPaletteList28, 0x0002EC8B, 0x0002ECBB },
	{ kPaletteList29, 0x0002ECBB, 0x0002ECEB },
	{ kPaletteList30, 0x0002ECEB, 0x0002ED27 },
	{ kPaletteList31, 0x0002ED27, 0x0002ED4E },
	{ kPaletteList32, 0x0002ED4F, 0x0002ED76 },
	{ kPaletteList33, 0x0002ED77, 0x0002EDB3 },
	{ kPutDownString, 0x00025BD6, 0x00025BFC },
	{ kWaitAmuletString, 0x00025C2A, 0x00025C67 },
	{ kBlackJewelString, 0x00025C96, 0x00025CB9 },
	{ kHealingTipString, 0x00025CF2, 0x00025D1F },
	{ kPoisonGoneString, 0x00025E06, 0x00025E42 },
	{ kHealing1Shapes, 0x000381F1, 0x0003828B },
	{ kHealing2Shapes, 0x0003828D, 0x0003835F },
	{ kThePoisonStrings, 0x000294B8, 0x0002954A },
	{ kFluteStrings, 0x00025B1E, 0x00025B78 },
	{ kPoisonDeathShapes, 0x0003865D, 0x000386E9 },
	{ kFluteShapes, 0x00038561, 0x0003865D },
	{ kWinter1Shapes, 0x00038361, 0x00038392 },
	{ kWinter2Shapes, 0x00038395, 0x0003848A },
	{ kWinter3Shapes, 0x0003848D, 0x000384A9 },
	{ kDrinkShapes, 0x00038185, 0x000381EF },
	{ kWispShapes, 0x000384A9, 0x0003855F },
	{ kMagicAnimShapes, 0x000386E9, 0x0003870C },
	{ kBranStoneShapes, 0x0003870D, 0x00038770 },
	{ kWispJewelStrings, 0x00025D4E, 0x00025DC3 },
	{ kMagicJewelStrings, 0x00025DE2, 0x00025DF5 },
	{ kFlaskFullString, 0x00029688, 0x000296A4 },
	{ kFullFlaskString, 0x00029568, 0x00029605 },
	{ kOutroReunionSeq, 0x0002B529, 0x0002BA70 },
	{ kOutroHomeString, 0x00025F7E, 0x00025F83 },
	{ kVeryCleverString, 0x00025F8E, 0x00025FC0 },
	{ kGUIStrings, 0x000291E0, 0x000293DC },
	{ kNewGameString, 0x0002919C, 0x000291B1 },
	{ kConfigStrings, 0x00029360, 0x000293AA},
	{ kKyra1TownsSFXwdTable, 0x0003A978, 0x0004CF80 },
	{ kKyra1TownsSFXbtTable, 0x0003A878, 0x0003A978 },
	{ kKyra1TownsCDATable, 0x0004D021, 0x0004D2E5 },
	{ kAudioTracks, 0x00027B8E, 0x00027BEB },
	{ kCreditsStrings, 0x0002AED8, 0x0002B464 },
	{ -1, 0, 0 }
};

const ExtractEntry kyra1FMTownsJ[] = {
	{ kIntroStrings, 0x0002837C, 0x00028977 },
	{ kItemNames, 0x00029C2C, 0x0002A1B3 },
	{ kTakenStrings, 0x00028980, 0x0002899F },
	{ kPlacedStrings, 0x000289AC, 0x000289B9 },
	{ kDroppedStrings, 0x000289F0, 0x000289FB },
	{ kNoDropStrings, 0x00027C3E, 0x00027C9F },
	{ kPutDownString, 0x00025BFE, 0x00025C27 },
	{ kWaitAmuletString, 0x00025C6A, 0x00025C93 },
	{ kBlackJewelString, 0x00025CBA, 0x00025CEF },
	{ kHealingTipString, 0x00025D22, 0x00025D4D },
	{ kPoisonGoneString, 0x00025E12, 0x00025E4F },
	{ kThePoisonStrings, 0x000294C8, 0x00029568 },
	{ kFluteStrings, 0x00025B3E, 0x00025B91 },
	{ kWispJewelStrings, 0x00025D7A, 0x00025DE1 },
	{ kMagicJewelStrings, 0x00025DF6, 0x00025E05 },
	{ kFlaskFullString, 0x000296A4, 0x000296C3 },
	{ kFullFlaskString, 0x00029608, 0x00029685 },
	{ kOutroHomeString, 0x00025F86, 0x00025F8D },
	{ kVeryCleverString, 0x00025FC2, 0x00025FF1 },
	{ kGUIStrings, 0x000368D1, 0x00036B30 },
	{ kNewGameString, 0x000291B4, 0x000291CF},
	{ kConfigStrings, 0x000290AC, 0x00029103 },
	{ -1, 0, 0 }
};

const Game kyra1TownsGames[] = {
	{ kKyra1, EN_ANY, kFMTownsVersionE, "5a3ad60ccd0f2e29463e0368cd14a60d", kyra1FMTownsE },
	{ kKyra1, JA_JPN, kFMTownsVersionJ, "5a3ad60ccd0f2e29463e0368cd14a60d", kyra1FMTownsJ },
	GAME_DUMMY_ENTRY
};
